@@ -250,8 +250,8 @@ if(isset($_GET['action'])) {
 			if($_POST['short_call_modify']) $sql.="short_call_limit='$_POST[short_call_limit]',short_call_disable='$_POST[short_call_disable]',";
 			if($_POST['short_time_modify']) $sql.="short_time='$_POST[short_time]',";
 			if($_POST['dev_disable_modify']) $sql.="dev_disable='$dev_disable',";
-			if($_POSY['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
-			if($_POSY['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
+			if($_POST['auto_reset_remain_modify']) $sql.="auto_reset_remain='$_POST[auto_reset_remain]',";
+			if($_POST['auto_reset_remain_s_modify']) $sql.="auto_reset_remain_s='$_POST[auto_reset_remain_s]',";
 			$sql.="sim_login=sim_login $where";
 			$db->query($sql);
 
